:mod:`~kanon.units.precision` --- Manage precision and algorithms on arithmetical operations
============================================================================================

.. automodapi:: kanon.units.precision
    :inherited-members:
